<?php
/**
 * BBP hooks.
 *
 * @since 0.1.26
 *
 */

class UBC_CLF_LITE_BBP {

	/**
	 * Set up filter hooks for main html tag classes
	 *
	 * @since 1.0.0
	 *
	 */
	public function init() {

		add_filter( 'bbppu_bookmark_icon', array( $this, 'ubc_wp_clf_lite_bbppu_icon' ), 10, 2 );
		add_filter( 'bbp_theme_before_topic_title', array( $this, 'bbp_lets_get_this_before_a_topic_title' ), 10, 2 );
		add_filter( 'bbp_after_get_the_content_parse_args', array( $this, 'bbp_enable_visual_editor' ), 10, 2 );
		add_filter( 'bbp_get_tiny_mce_plugins', array( $this, 'bbp_tinymce_paste_plain_text' ), 10, 2 );

	}

	/**
	 * Plugin path
	 *
	 * @since 0.1.26
	 *
	 * @return $ubc_clf_lite_get_file  file path
	 */

	public function ubc_clf_lite_get_stylesheet_directory( $folders, $file ) {

		$startPath = trailingslashit( get_stylesheet_directory_uri() ) . $folders;
		$templateNames = $file;

		$ubc_clf_lite_get_file = trailingslashit( $startPath ).$templateNames;

		return $ubc_clf_lite_get_file;

	}

	/**
	 * If BBPress topic is unread show unread text. Helps with ui and accesiblity
	 * Using BBP Pencil Unread - https://github.com/gordielachance/bbpress-pencil-unread/
	 *
	 * @since 0.1.26
	 *
	 * @param(bool) $bbppu_has_user_read()
	 */

	public function bbp_lets_get_this_before_a_topic_title( $topic_id, $user_id = false ) {

		if ( ! function_exists( 'bbppu' ) ) {

			return;

		}

		$get_post_type 			 = get_post_type();
		$topic_id 		 			 = bbp_get_topic_id();
		$bbppu_has_user_read = bbppu()->has_user_read( $topic_id, $user_id );

		if ( false === $bbppu_has_user_read && 'topic' == $get_post_type ) :

			echo '<aside class="bbp-post-notifications bbppu-unread-post"><h6>Unread post(s)</h6></aside>';

		endif;

	}
	/** end bbp_lets_get_this_before_a_topic_title() **/

	/**
	* Hook for bbppu mark as read plugin. ADD bookmark url attributes .
	*
	* @since 0.1.26
	* @return $bbppu_bookmark_url_attr - (array) attributes: html, classes, icon, title
	*/

	public function ubc_wp_clf_lite_bbppu_icon( $bbppu_bookmark_url_attr ) {

		if ( ! function_exists( 'bbppu' ) ) {

			return;

		}

		$icon = $this->ubc_clf_lite_get_stylesheet_directory( $folders = 'svg-optim', $file = 'bookmark.svg' );

		$icon_img = '<img alt="bookmark icon" width="25" height="25" src="'. esc_url( $icon ) .'" />';

		$url_new_atts = array(
			'html' 		=> 'data-tooltip aria-haspopup="true" data-disable-hover="false" tabindex="1"',
			'classes'	=> 'has-tip',
			'icon'		=> $icon_img,
			'title'		=> __( 'Go to last read','ubc-wp-clf-lite' ),
		);

		$bbppu_bookmark_url_attr = $url_new_atts;

			return $bbppu_bookmark_url_attr;

	}

	/* end ubc_wp_clf_lite_bbppu_icon() **/

	/**
	* Hook for bbppu mark as read plugin. ADD bookmark url attributes .
	*
	* @since 0.1.35
	* @return $args - (array)
	*/

	public function bbp_enable_visual_editor( $args = array() ) {

		$args['tinymce'] = true;
		$args['teeny'] = true;
		$args['quicktags'] = false;

			return $args;

	}

	public function bbp_tinymce_paste_plain_text( $plugins = array() ) {

		$plugins[] = 'paste';
		return $plugins;

	}

}

// Initialize our child theme changes.
add_action( 'after_setup_theme', 'after_setup_theme_ubc_clf_lite_bbp_init', 15 );


/**
 * Initialize the UBC_CLF_Lite_Customizer class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme_ubc_clf_lite_bbp_init() {

	$UBC_CLF_Html_Classes = new UBC_CLF_LITE_BBP();
	$UBC_CLF_Html_Classes->init();

}/* after_setup_theme_ubc_clf_lite_bbp_init() */
